@@ -80,10 +80,10 @@ class GenericSessionConfig(Generic[ConnectionT, EngineT, SessionT]):
     autoflush: "Union[bool, EmptyType]" = Empty
     """When ``True``, all query operations will issue a flush call to this :class:`Session <sqlalchemy.orm.Session>`
     before proceeding"""
-    bind: "Union[EngineT, ConnectionT, None, EmptyType]" = Empty
+    bind: "Optional[Union[EngineT, ConnectionT, EmptyType]]" = Empty
     """The :class:`Engine <sqlalchemy.engine.Engine>` or :class:`Connection <sqlalchemy.engine.Connection>` that new
     :class:`Session <sqlalchemy.orm.Session>` objects will be bound to."""
-    binds: "Union[dict[Union[type[Any], Mapper[Any], TableClause, str], Union[EngineT, ConnectionT]], None, EmptyType]" = Empty
+    binds: "Optional[Union[dict[Union[type[Any], Mapper[Any], TableClause, str], Union[EngineT, ConnectionT]], EmptyType]]" = Empty
     """A dictionary which may specify any number of :class:`Engine <sqlalchemy.engine.Engine>` or :class:`Connection
     <sqlalchemy.engine.Connection>` objects as the source of connectivity for SQL operations on a per-entity basis. The
     keys of the dictionary consist of any series of mapped classes, arbitrary Python classes that are bases for mapped
@@ -94,18 +94,18 @@ class GenericSessionConfig(Generic[ConnectionT, EngineT, SessionT]):
     """Class to use in order to create new :class:`Session <sqlalchemy.orm.Session>` objects."""
     expire_on_commit: "Union[bool, EmptyType]" = Empty
     """If ``True``, all instances will be expired after each commit."""
-    info: "Union[dict[str, Any], None, EmptyType]" = Empty
+    info: "Optional[Union[dict[str, Any], EmptyType]]" = Empty
     """Optional dictionary of information that will be available via the
     :attr:`Session.info <sqlalchemy.orm.Session.info>`"""
     join_transaction_mode: "Union[JoinTransactionMode, EmptyType]" = Empty
     """Describes the transactional behavior to take when a given bind is a Connection that has already begun a
     transaction outside the scope of this Session; in other words the
     :attr:`Connection.in_transaction() <sqlalchemy.Connection.in_transaction>` method returns True."""
-    query_cls: "Union[type[Query], None, EmptyType]" = Empty  # pyright: ignore[reportMissingTypeArgument]
+    query_cls: "Optional[Union[type[Query], EmptyType]]" = Empty  # pyright: ignore[reportMissingTypeArgument]
     """Class which should be used to create new Query objects, as returned by the
     :attr:`Session.query() <sqlalchemy.orm.Session.query>` method."""
     twophase: "Union[bool, EmptyType]" = Empty
-    """When ``True``, all transactions will be started as a “two phase” transaction, i.e. using the “two phase”
+    """When ``True``, all transactions will be started as a "two phase" transaction, i.e. using the "two phase"
     semantics of the database in use along with an XID. During a :attr:`commit() <sqlalchemy.orm.Session.commit>`, after
     :attr:`flush() <sqlalchemy.orm.Session.flush>` has been issued for all attached databases, the
     :attr:`TwoPhaseTransaction.prepare() <sqlalchemy.engine.TwoPhaseTransaction.prepare>` method on each database`s
@@ -138,7 +138,7 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
         :class:`sqlalchemy.orm.sessionmaker`
         :class:`sqlalchemy.ext.asyncio.async_sessionmaker`
     """
-    connection_string: "Union[str, None]" = field(default=None)
+    connection_string: "Optional[str]" = field(default=None)
     """Database connection string in one of the formats supported by SQLAlchemy.
 
     Notes:
@@ -151,12 +151,12 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
 
     The configuration options are documented in the SQLAlchemy documentation.
     """
-    session_maker: "Union[Callable[[], SessionT], None]" = None
+    session_maker: "Optional[Callable[[], SessionT]]" = None
     """Callable that returns a session.
 
     If provided, the plugin will use this rather than instantiate a sessionmaker.
     """
-    engine_instance: "Union[EngineT, None]" = None
+    engine_instance: "Optional[EngineT]" = None
     """Optional engine to use.
 
     If set, the plugin will use the provided instance rather than instantiate an engine.
@@ -164,17 +164,23 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
     create_all: bool = False
     """If true, all models are automatically created on engine creation."""
 
-    metadata: "Union[MetaData, None]" = None
+    metadata: "Optional[MetaData]" = None
     """Optional metadata to use.
 
       If set, the plugin will use the provided instance rather than the default metadata."""
+    bind_key: "Optional[str]" = None
+    """Bind key to register a metadata to a specific engine configuration."""
     enable_touch_updated_timestamp_listener: bool = True
     """Enable Created/Updated Timestamp event listener.
 
     This is a listener that will update ``created_at`` and ``updated_at`` columns on record modification.
     Disable if you plan to bring your own update mechanism for these columns"""
-    bind_key: "Union[str, None]" = None
-    """Bind key to register a metadata to a specific engine configuration."""
+    enable_file_object_listener: bool = True
+    """Enable FileObject listener.
+
+    This is a listener that will automatically save and delete :class:`FileObject <advanced_alchemy.types.file_object.FileObject>` instances when they are saved or deleted.
+
+    Disable if you plan to bring your own save/delete mechanism for these columns"""
     _SESSION_SCOPE_KEY_REGISTRY: "ClassVar[set[str]]" = field(init=False, default=cast("set[str]", set()))
     """Internal counter for ensuring unique identification of session scope keys in the class."""
     _ENGINE_APP_STATE_KEY_REGISTRY: "ClassVar[set[str]]" = field(init=False, default=cast("set[str]", set()))
@@ -197,6 +203,10 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
             from advanced_alchemy._listeners import touch_updated_timestamp
 
             event.listen(Session, "before_flush", touch_updated_timestamp)
+        if self.enable_file_object_listener:
+            from advanced_alchemy._listeners import setup_file_object_listeners
+
+            setup_file_object_listeners()
 
     def __hash__(self) -> int:  # pragma: no cover
         return hash(
@@ -234,6 +244,9 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
     def get_engine(self) -> EngineT:
         """Return an engine. If none exists yet, create one.
 
+        Raises:
+            ImproperConfigurationError: if neither `connection_string` nor `engine_instance` are provided.
+
         Returns:
             :class:`sqlalchemy.Engine` or :class:`sqlalchemy.ext.asyncio.AsyncEngine` instance used by the plugin.
         """
@@ -246,12 +259,13 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
 
         engine_config = self.engine_config_dict
         try:
-            return self.create_engine_callable(self.connection_string, **engine_config)
+            self.engine_instance = self.create_engine_callable(self.connection_string, **engine_config)
         except TypeError:
             # likely due to a dialect that doesn't support json type
             del engine_config["json_deserializer"]
             del engine_config["json_serializer"]
-            return self.create_engine_callable(self.connection_string, **engine_config)
+            self.engine_instance = self.create_engine_callable(self.connection_string, **engine_config)
+        return self.engine_instance
 
     def create_session_maker(self) -> "Callable[[], SessionT]":  # pragma: no cover
         """Get a session maker. If none exists yet, create one.
@@ -265,7 +279,8 @@ class GenericSQLAlchemyConfig(Generic[EngineT, SessionT, SessionMakerT]):
         session_kws = self.session_config_dict
         if session_kws.get("bind") is None:
             session_kws["bind"] = self.get_engine()
-        return cast("Callable[[], SessionT]", self.session_maker_class(**session_kws))
+        self.session_maker = cast("Callable[[], SessionT]", self.session_maker_class(**session_kws))
+        return self.session_maker
 
 
 @dataclass
