@@ -1,3 +1,4 @@
+# ruff: noqa: PLR0904
 from collections.abc import AsyncGenerator, Generator, Sequence
 from contextlib import asynccontextmanager, contextmanager
 from typing import TYPE_CHECKING, Any, Callable, Optional, Union, cast, overload
@@ -14,8 +15,8 @@ try:
     SANIC_INSTALLED = True
 except ModuleNotFoundError:  # pragma: no cover
     SANIC_INSTALLED = False  # pyright: ignore[reportConstantRedefinition]
-    Extension = type("Extension", (), {})  # type: ignore  # noqa: PGH003
-    Extend = type("Extend", (), {})  # type: ignore  # noqa: PGH003
+    Extension = type("Extension", (), {})  # type: ignore
+    Extend = type("Extend", (), {})  # type: ignore
 
 if TYPE_CHECKING:
     from sanic import Sanic
@@ -65,7 +66,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
 
     @property
     def sanic_app(self) -> "Sanic[Any, Any]":
-        """The Sanic app."""
+        """The Sanic app.
+
+        Raises:
+            ImproperConfigurationError: If the app is not initialized.
+        """
         if self._app is None:  # pragma: no cover
             msg = "AdvancedAlchemy has not been initialized with a Sanic app."
             raise ImproperConfigurationError(msg)
@@ -87,7 +92,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
             config.init_app(self.sanic_app, bootstrap)  # pyright: ignore[reportUnknownMemberType,reportUnknownArgumentType]
 
     def map_configs(self) -> dict[str, Union["SQLAlchemyAsyncConfig", "SQLAlchemySyncConfig"]]:
-        """Maps the configs to the session bind keys."""
+        """Maps the configs to the session bind keys.
+
+        Returns:
+            A dictionary mapping bind keys to SQLAlchemy configurations.
+        """
         mapped_configs: dict[str, Union[SQLAlchemyAsyncConfig, SQLAlchemySyncConfig]] = {}
         for config in self.sqlalchemy_config:
             if config.bind_key is None:
@@ -96,7 +105,14 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return mapped_configs
 
     def get_config(self, key: Optional[str] = None) -> Union["SQLAlchemyAsyncConfig", "SQLAlchemySyncConfig"]:
-        """Get the config for the given key."""
+        """Get the config for the given key.
+
+        Returns:
+            The config for the given key.
+
+        Raises:
+            ImproperConfigurationError: If the config is not found.
+        """
         if key is None:
             key = "default"
         if key == "default" and len(self.sqlalchemy_config) == 1:
@@ -108,7 +124,14 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return config
 
     def get_async_config(self, key: Optional[str] = None) -> "SQLAlchemyAsyncConfig":
-        """Get the async config for the given key."""
+        """Get the async config for the given key.
+
+        Returns:
+            The async config for the given key.
+
+        Raises:
+            ImproperConfigurationError: If the config is not an async config.
+        """
         config = self.get_config(key)
         if not isinstance(config, SQLAlchemyAsyncConfig):  # pragma: no cover
             msg = "Expected an async config, but got a sync config"
@@ -116,7 +139,14 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return config
 
     def get_sync_config(self, key: Optional[str] = None) -> "SQLAlchemySyncConfig":
-        """Get the sync config for the given key."""
+        """Get the sync config for the given key.
+
+        Returns:
+            The sync config for the given key.
+
+        Raises:
+            ImproperConfigurationError: If the config is not an sync config.
+        """
         config = self.get_config(key)
         if not isinstance(config, SQLAlchemySyncConfig):  # pragma: no cover
             msg = "Expected a sync config, but got an async config"
@@ -127,14 +157,22 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
     async def with_async_session(
         self, key: Optional[str] = None
     ) -> AsyncGenerator["AsyncSession", None]:  # pragma: no cover
-        """Context manager for getting an async session."""
+        """Context manager for getting an async session.
+
+        Yields:
+            An AsyncSession instance.
+        """
         config = self.get_async_config(key)
         async with config.get_session() as session:
             yield session
 
     @contextmanager
     def with_sync_session(self, key: Optional[str] = None) -> Generator["Session", None]:  # pragma: no cover
-        """Context manager for getting a sync session."""
+        """Context manager for getting a sync session.
+
+        Yields:
+            A Session instance.
+        """
         config = self.get_sync_config(key)
         with config.get_session() as session:
             yield session
@@ -152,7 +190,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         request: "Request",
         config: Union["SQLAlchemyAsyncConfig", "SQLAlchemySyncConfig"],  # pragma: no cover
     ) -> Union["Session", "AsyncSession"]:  # pragma: no cover
-        """Get the session for the given key."""
+        """Get the session for the request and config.
+
+        Returns:
+            The session for the request and config.
+        """
         session = getattr(request.ctx, config.session_key, None)
         if session is None:
             setattr(request.ctx, config.session_key, config.get_session())
@@ -161,24 +203,40 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
     def get_session(
         self, request: "Request", key: Optional[str] = None
     ) -> Union["Session", "AsyncSession"]:  # pragma: no cover
-        """Get the session for the given key."""
+        """Get the session for the given key.
+
+        Returns:
+            The session for the given key.
+        """
         config = self.get_config(key)
         return self._get_session_from_request(request, config)
 
     def get_async_session(self, request: "Request", key: Optional[str] = None) -> "AsyncSession":  # pragma: no cover
-        """Get the async session for the given key."""
+        """Get the async session for the given key.
+
+        Returns:
+            The async session for the given key.
+        """
         config = self.get_async_config(key)
         return self._get_session_from_request(request, config)
 
     def get_sync_session(self, request: "Request", key: Optional[str] = None) -> "Session":  # pragma: no cover
-        """Get the sync session for the given key."""
+        """Get the sync session for the given key.
+
+        Returns:
+            The sync session for the given key.
+        """
         config = self.get_sync_config(key)
         return self._get_session_from_request(request, config)
 
     def provide_session(
         self, key: Optional[str] = None
     ) -> Callable[["Request"], Union["Session", "AsyncSession"]]:  # pragma: no cover
-        """Get the session for the given key."""
+        """Get session provider for the given key.
+
+        Returns:
+            The session provider for the given key.
+        """
         config = self.get_config(key)
 
         def _get_session(request: "Request") -> Union["Session", "AsyncSession"]:
@@ -189,7 +247,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
     def provide_async_session(
         self, key: Optional[str] = None
     ) -> Callable[["Request"], "AsyncSession"]:  # pragma: no cover
-        """Get the async session for the given key."""
+        """Get async session provider for the given key.
+
+        Returns:
+            The async session provider for the given key.
+        """
         config = self.get_async_config(key)
 
         def _get_session(request: Request) -> "AsyncSession":
@@ -198,7 +260,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return _get_session
 
     def provide_sync_session(self, key: Optional[str] = None) -> Callable[[Request], "Session"]:  # pragma: no cover
-        """Get the sync session for the given key."""
+        """Get sync session provider for the given key.
+
+        Returns:
+            The sync session provider for the given key.
+        """
         config = self.get_sync_config(key)
 
         def _get_session(request: Request) -> "Session":
@@ -207,24 +273,40 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return _get_session
 
     def get_engine(self, key: Optional[str] = None) -> Union["Engine", "AsyncEngine"]:  # pragma: no cover
-        """Get the engine for the given key."""
+        """Get the engine for the given key.
+
+        Returns:
+            The engine for the given key.
+        """
         config = self.get_config(key)
         return config.get_engine()
 
     def get_async_engine(self, key: Optional[str] = None) -> "AsyncEngine":  # pragma: no cover
-        """Get the async engine for the given key."""
+        """Get the async engine for the given key.
+
+        Returns:
+            The async engine for the given key.
+        """
         config = self.get_async_config(key)
         return config.get_engine()
 
     def get_sync_engine(self, key: Optional[str] = None) -> "Engine":  # pragma: no cover
-        """Get the sync engine for the given key."""
+        """Get the sync engine for the given key.
+
+        Returns:
+            The sync engine for the given key.
+        """
         config = self.get_sync_config(key)
         return config.get_engine()
 
     def provide_engine(
         self, key: Optional[str] = None
     ) -> Callable[[], Union["Engine", "AsyncEngine"]]:  # pragma: no cover
-        """Get the engine for the given key."""
+        """Get the engine for the given key.
+
+        Returns:
+            A callable that returns the engine.
+        """
         config = self.get_config(key)
 
         def _get_engine() -> Union["Engine", "AsyncEngine"]:
@@ -233,7 +315,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return _get_engine
 
     def provide_async_engine(self, key: Optional[str] = None) -> Callable[[], "AsyncEngine"]:  # pragma: no cover
-        """Get the async engine for the given key."""
+        """Get the async engine for the given key.
+
+        Returns:
+            A callable that returns the engine.
+        """
         config = self.get_async_config(key)
 
         def _get_engine() -> "AsyncEngine":
@@ -242,7 +328,11 @@ class AdvancedAlchemy(Extension):  # type: ignore[no-untyped-call]  # pyright: i
         return _get_engine
 
     def provide_sync_engine(self, key: Optional[str] = None) -> Callable[[], "Engine"]:  # pragma: no cover
-        """Get the sync engine for the given key."""
+        """Get the sync engine for the given key.
+
+        Returns:
+            A callable that returns the engine.
+        """
         config = self.get_sync_config(key)
 
         def _get_engine() -> "Engine":
