@@ -1,5 +1,6 @@
 from typing import TYPE_CHECKING, Any, Union
 
+from sqlalchemy import UnaryExpression
 from sqlalchemy.orm import InstrumentedAttribute
 from typing_extensions import TypeAlias, TypeVar
 
@@ -69,12 +70,13 @@ SQLAlchemyAsyncRepositoryT = TypeVar(
 
 :class:`~advanced_alchemy.repository.SQLAlchemyAsyncRepository`
 """
-OrderingPair: TypeAlias = tuple[Union[str, InstrumentedAttribute[Any]], bool]
+OrderingPair: TypeAlias = Union[tuple[Union[str, InstrumentedAttribute[Any]], bool], UnaryExpression[Any]]
 """Type alias for ordering pairs.
 
 A tuple of (column, ascending) where:
 - column: Union[str, :class:`sqlalchemy.orm.InstrumentedAttribute`]
 - ascending: bool
+- or a :class:`sqlalchemy.sql.elements.UnaryExpression` which is the standard way to express an ordering in SQLAlchemy
 
 This type is used to specify ordering criteria for repository queries.
 """
