@@ -58,7 +58,7 @@ pytestmark = [
             ],
         ),
         pytest.param(
-            "oracle23c_engine",
+            "oracle23ai_engine",
             marks=[
                 pytest.mark.oracledb_sync,
                 pytest.mark.integration,
@@ -159,7 +159,7 @@ def sync_sqlalchemy_config(request: FixtureRequest) -> Generator[SQLAlchemySyncC
             ],
         ),
         pytest.param(
-            "oracle23c_async_engine",
+            "oracle23ai_async_engine",
             marks=[
                 pytest.mark.oracledb_async,
                 pytest.mark.integration,
