@@ -3,15 +3,20 @@
 from __future__ import annotations
 
 import inspect
+import unittest.mock
 import uuid
 from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, Any, cast
 from unittest.mock import MagicMock, patch
 
+from litestar import Litestar, get
 from litestar.di import Provide
+from litestar.openapi.config import OpenAPIConfig
+from litestar.testing import TestClient
 from sqlalchemy import FromClause, String, select
 from sqlalchemy.orm import DeclarativeBase, Mapped, Mapper, mapped_column
 
+from advanced_alchemy.extensions.litestar.plugins.init.plugin import signature_namespace_values
 from advanced_alchemy.extensions.litestar.providers import (
     DEPENDENCY_DEFAULTS,
     DependencyCache,
@@ -28,7 +33,9 @@ from advanced_alchemy.extensions.litestar.providers import (
 from advanced_alchemy.filters import (
     BeforeAfter,
     CollectionFilter,
+    FilterTypes,
     LimitOffset,
+    NotInCollectionFilter,
     OrderBy,
     SearchFilter,
 )
@@ -167,6 +174,26 @@ def test_create_sync_service_provider() -> None:
     assert isinstance(svc, TestSyncService)
 
 
+def test_create_sync_service_provider_custom() -> None:
+    """Test creating a sync service provider."""
+    provider = create_service_provider(TestSyncService, config=MagicMock(session_dependency_key="testing_session"))
+
+    # Ensure the provider is callable
+    assert callable(provider)
+    svc = next(provider(testing_session=MagicMock()))
+    assert isinstance(svc, TestSyncService)
+
+
+def test_create_sync_service_provider_positional() -> None:
+    """Test creating an async service provider."""
+    provider = create_service_provider(TestSyncService, config=MagicMock(session_dependency_key="testing_session"))
+
+    # Ensure the provider is callable
+    assert callable(provider)
+    svc = next(provider(MagicMock()))
+    assert isinstance(svc, TestSyncService)
+
+
 async def test_create_async_service_provider() -> None:
     """Test creating an async service provider."""
     provider = create_service_provider(TestAsyncService)
@@ -177,6 +204,26 @@ async def test_create_async_service_provider() -> None:
     assert isinstance(svc, TestAsyncService)
 
 
+async def test_create_async_service_provider_custom() -> None:
+    """Test creating an async service provider."""
+    provider = create_service_provider(TestAsyncService, config=MagicMock(session_dependency_key="testing_session"))
+
+    # Ensure the provider is callable
+    assert callable(provider)
+    svc = await anext_(provider(testing_session=MagicMock()))
+    assert isinstance(svc, TestAsyncService)
+
+
+async def test_create_async_service_provider_positional() -> None:
+    """Test creating an async service provider."""
+    provider = create_service_provider(TestAsyncService, config=MagicMock(session_dependency_key="testing_session"))
+
+    # Ensure the provider is callable
+    assert callable(provider)
+    svc = await anext_(provider(MagicMock()))
+    assert isinstance(svc, TestAsyncService)
+
+
 def test_create_async_service_dependencies() -> None:
     """Test creating async service dependencies."""
     with patch("advanced_alchemy.extensions.litestar.providers.create_service_provider") as mock_create_provider:
@@ -363,10 +410,10 @@ def test_limit_offset_filter() -> None:
     config = cast(FilterConfig, {"pagination_type": "limit_offset", "default_limit": 10, "max_limit": 100})
     deps = _create_statement_filters(config)
 
-    assert "limit_offset" in deps
+    assert "limit_offset_filter" in deps
     assert "filters" in deps
     # Test the provider function
-    provider_func = deps["limit_offset"].dependency
+    provider_func = deps["limit_offset_filter"].dependency
 
     f = provider_func(current_page=2, page_size=5)
     assert isinstance(f, LimitOffset)
@@ -379,24 +426,62 @@ def test_order_by_filter() -> None:
     config = cast(FilterConfig, {"sort_field": "name"})
     deps = _create_statement_filters(config)
 
-    assert "order_by" in deps
+    assert "order_by_filter" in deps
     assert "filters" in deps
 
     # Test the provider function
-    provider_func = deps["order_by"].dependency
+    provider_func = deps["order_by_filter"].dependency
     f = provider_func(field_name="name", sort_order="desc")
     assert isinstance(f, OrderBy)
     assert f.field_name == "name"
     assert f.sort_order == "desc"
 
 
+def test_not_in_filter() -> None:
+    """Test creating not_in filter dependency."""
+    deps = _create_statement_filters({"not_in_fields": ["status"]})
+
+    assert "status_not_in_filter" in deps
+    assert "filters" in deps
+
+    # Test the provider function
+    provider_func = deps["status_not_in_filter"].dependency
+    f = provider_func(values=["pending", "failed"])
+    assert isinstance(f, NotInCollectionFilter)
+    assert f.field_name == "status"
+    assert f.values == ["pending", "failed"]
+
+    # Test with None
+    f_none = provider_func(values=None)
+    assert f_none is None
+
+
+def test_in_filter() -> None:
+    """Test creating in filter dependency."""
+    deps = _create_statement_filters({"in_fields": ["tag"]})
+
+    assert "tag_in_filter" in deps
+    assert "filters" in deps
+
+    # Test the provider function
+    provider_func = deps["tag_in_filter"].dependency
+    f = provider_func(values=["python", "litestar"])
+    assert isinstance(f, CollectionFilter)
+    assert f.field_name == "tag"
+    assert f.values == ["python", "litestar"]
+
+    # Test with None
+    f_none = provider_func(values=None)
+    assert f_none is None
+
+
 def test_custom_dependency_defaults() -> None:
     """Test using custom dependency defaults."""
 
     class CustomDefaults(DependencyDefaults):
         """Custom dependency defaults."""
 
-        LIMIT_OFFSET_DEPENDENCY_KEY = "page"
+        LIMIT_OFFSET_FILTER_DEPENDENCY_KEY = "page"
         ID_FILTER_DEPENDENCY_KEY = "ids"
         DEFAULT_PAGINATION_SIZE = 100
 
@@ -438,8 +523,7 @@ def test_id_filter_aggregation() -> None:
 
 def test_created_at_filter_aggregation() -> None:
     """Test aggregation with created_at filter."""
-    config = cast(FilterConfig, {"created_at": "created_at"})
-    aggregate_func = _create_filter_aggregate_function(config)
+    aggregate_func = _create_filter_aggregate_function({"created_at": True})
 
     # Check signature
     sig = inspect.signature(aggregate_func)
@@ -455,8 +539,7 @@ def test_created_at_filter_aggregation() -> None:
 
 def test_updated_at_filter_aggregation() -> None:
     """Test aggregation with updated_at filter."""
-    config = cast(FilterConfig, {"updated_at": "updated_at"})
-    aggregate_func = _create_filter_aggregate_function(config)
+    aggregate_func = _create_filter_aggregate_function({"updated_at": True})
 
     # Check signature
     sig = inspect.signature(aggregate_func)
@@ -472,8 +555,7 @@ def test_updated_at_filter_aggregation() -> None:
 
 def test_search_filter_aggregation() -> None:
     """Test aggregation with search filter."""
-    config = cast(FilterConfig, {"search": ["name"]})
-    aggregate_func = _create_filter_aggregate_function(config)
+    aggregate_func = _create_filter_aggregate_function({"search": ["name"]})
 
     # Check signature
     sig = inspect.signature(aggregate_func)
@@ -497,16 +579,15 @@ def test_search_filter_aggregation() -> None:
 
 def test_limit_offset_filter_aggregation() -> None:
     """Test aggregation with limit_offset filter."""
-    config = cast(FilterConfig, {"pagination_type": "limit_offset"})
-    aggregate_func = _create_filter_aggregate_function(config)
+    aggregate_func = _create_filter_aggregate_function({"pagination_type": "limit_offset"})
 
     # Check signature
     sig = inspect.signature(aggregate_func)
-    assert "limit_offset" in sig.parameters
+    assert "limit_offset_filter" in sig.parameters
 
     # Simulate calling with filter
     mock_filter = MagicMock(spec=LimitOffset)
-    result = aggregate_func(limit_offset=mock_filter)
+    result = aggregate_func(limit_offset_filter=mock_filter)
 
     assert isinstance(result, list)
     assert mock_filter in result
@@ -514,32 +595,71 @@ def test_limit_offset_filter_aggregation() -> None:
 
 def test_order_by_filter_aggregation() -> None:
     """Test aggregation with order_by filter."""
-    config = cast(FilterConfig, {"sort_field": "name"})
-    aggregate_func = _create_filter_aggregate_function(config)
+    aggregate_func = _create_filter_aggregate_function({"sort_field": "name"})
 
     # Check signature
     sig = inspect.signature(aggregate_func)
-    assert "order_by" in sig.parameters
+    assert "order_by_filter" in sig.parameters
 
     # Mock order_by filter with valid field_name
     mock_filter = MagicMock(spec=OrderBy)
     mock_filter.field_name = "name"
 
-    result = aggregate_func(order_by=mock_filter)
+    result = aggregate_func(order_by_filter=mock_filter)
 
     assert isinstance(result, list)
     assert mock_filter in result
 
     # Test with invalid order_by filter (None field_name)
     mock_filter.field_name = None
-    result = aggregate_func(order_by=mock_filter)
+    result = aggregate_func(order_by_filter=mock_filter)
     assert mock_filter not in result
 
 
+def test_not_in_filter_aggregation() -> None:
+    """Test aggregation with not_in filter."""
+    aggregate_func = _create_filter_aggregate_function({"not_in_fields": ["status"]})
+    # Check signature
+    sig = inspect.signature(aggregate_func)
+    assert "status_not_in_filter" in sig.parameters
+
+    # Simulate calling with filter
+    mock_filter = MagicMock(spec=NotInCollectionFilter)
+    result = aggregate_func(status_not_in_filter=mock_filter)
+
+    assert isinstance(result, list)
+    assert mock_filter in result
+
+    # Simulate calling without filter (value is None)
+    result_none = aggregate_func(status_not_in_filter=None)
+    assert mock_filter not in result_none
+
+
+def test_in_filter_aggregation() -> None:
+    """Test aggregation with in filter."""
+    config = cast(FilterConfig, {"in_fields": ["tag"]})
+    aggregate_func = _create_filter_aggregate_function(config)
+
+    # Check signature
+    sig = inspect.signature(aggregate_func)
+    assert "tag_in_filter" in sig.parameters
+
+    # Simulate calling with filter
+    mock_filter = MagicMock(spec=CollectionFilter)
+    result = aggregate_func(tag_in_filter=mock_filter)
+
+    assert isinstance(result, list)
+    assert mock_filter in result
+
+    # Simulate calling without filter (value is None)
+    result_none = aggregate_func(tag_in_filter=None)
+    assert mock_filter not in result_none
+
+
 def test_multiple_filters_aggregation() -> None:
     """Test aggregation with multiple filters."""
-    config = cast(
-        FilterConfig,
+
+    aggregate_func = _create_filter_aggregate_function(
         {
             "id_filter": int,
             "created_at": True,
@@ -547,19 +667,21 @@ def test_multiple_filters_aggregation() -> None:
             "search": "name",
             "pagination_type": "limit_offset",
             "sort_field": "name",
-        },
+            "not_in_fields": ["status"],
+            "in_fields": ["tag"],
+        }
     )
 
-    aggregate_func = _create_filter_aggregate_function(config)
-
     # Check signature has all parameters
     sig = inspect.signature(aggregate_func)
     assert "id_filter" in sig.parameters
     assert "created_filter" in sig.parameters
     assert "updated_filter" in sig.parameters
     assert "search_filter" in sig.parameters
-    assert "limit_offset" in sig.parameters
-    assert "order_by" in sig.parameters
+    assert "limit_offset_filter" in sig.parameters
+    assert "order_by_filter" in sig.parameters
+    assert "status_not_in_filter" in sig.parameters
+    assert "tag_in_filter" in sig.parameters
 
     # Simulate calling with multiple filters
     mock_id_filter = MagicMock(spec=CollectionFilter)
@@ -569,23 +691,133 @@ def test_multiple_filters_aggregation() -> None:
     mock_search_filter.field_name = "name"
     mock_search_filter.value = "test"
     mock_limit_offset = MagicMock(spec=LimitOffset)
-    mock_order_by = MagicMock(spec=OrderBy)
-    mock_order_by.field_name = "name"
+    mock_order_by_filter = MagicMock(spec=OrderBy)
+    mock_order_by_filter.field_name = "name"
+    mock_not_in_filter = MagicMock(spec=NotInCollectionFilter)
+    mock_in_filter = MagicMock(spec=CollectionFilter)
 
     result = aggregate_func(
         id_filter=mock_id_filter,
         created_filter=mock_created_filter,
         updated_filter=mock_updated_filter,
         search_filter=mock_search_filter,
-        limit_offset=mock_limit_offset,
-        order_by=mock_order_by,
+        limit_offset_filter=mock_limit_offset,
+        order_by_filter=mock_order_by_filter,
+        status_not_in_filter=mock_not_in_filter,
+        tag_in_filter=mock_in_filter,
     )
 
     # Verify all filters are included
-    assert len(result) == 6
+    assert len(result) == 8
     assert mock_id_filter in result
     assert mock_created_filter in result
     assert mock_updated_filter in result
     assert mock_search_filter in result
     assert mock_limit_offset in result
-    assert mock_order_by in result
+    assert mock_order_by_filter in result
+    assert mock_not_in_filter in result
+    assert mock_in_filter in result
+
+
+@unittest.mock.patch(
+    "advanced_alchemy.extensions.litestar.providers.create_filter_dependencies",
+    wraps=create_filter_dependencies,  # Call the original function logic
+)
+def test_litestar_openapi_schema(mock_create_filters: unittest.mock.MagicMock) -> None:
+    """Test OpenAPI schema generation for filter dependencies."""
+
+    filter_config = {
+        "id_filter": uuid.UUID,  # Example using UUID
+        "id_field": "guid",
+        "created_at": True,
+        "updated_at": True,
+        "pagination_type": "limit_offset",
+        "pagination_size": 25,
+        "search": "name,description",
+        "search_ignore_case": True,
+        "sort_field": "name",
+        "sort_order": "asc",
+        "not_in_fields": ["status", "category"],
+        "in_fields": ["tag", "region"],
+    }
+    # Call the mocked function, which wraps the original
+    filter_dependencies = mock_create_filters(filter_config)
+
+    @get("/test")
+    async def test_handler(filters: list[FilterTypes]) -> list[str]:
+        """Dummy handler to test schema generation."""
+        return [type(f).__name__ for f in filters]
+
+    app = Litestar(
+        route_handlers=[test_handler],
+        signature_namespace=signature_namespace_values,
+        dependencies=filter_dependencies,  # Provide all dependencies to the app
+        openapi_config=OpenAPIConfig(
+            title="Test API", version="1.0.0", use_handler_docstrings=True, path="/schema"
+        ),  # Explicitly enable OpenAPI with specific path
+    )
+    client = TestClient(app)
+
+    # Fetch the OpenAPI schema (using the exact path from Litestar's default config)
+    response = client.get("/schema/openapi.json")
+    assert response.status_code == 200, (
+        f"Failed to get schema, status: {response.status_code}, content: {response.text[:200]}"
+    )
+    schema = response.json()
+
+    # Find the parameters for the /test endpoint
+    path_item = schema.get("paths", {}).get("/test", {}).get("get", {})
+    parameters = path_item.get("parameters", [])
+
+    # Assert all expected parameter names are present
+    param_names = {p["name"] for p in parameters}
+    expected_params = {
+        "ids",  # from id_filter, alias based on id_field 'guid' might not be reflected here, Litestar uses parameter name
+        "createdBefore",
+        "createdAfter",
+        "updatedBefore",
+        "updatedAfter",
+        "currentPage",
+        "pageSize",
+        "searchString",
+        "searchIgnoreCase",
+        "orderBy",
+        "sortOrder",
+        "statusNotIn",
+        "categoryNotIn",
+        "tagIn",
+        "regionIn",
+    }
+    assert param_names == expected_params
+
+    # Check details of specific parameters
+
+    # ids (based on id_filter: uuid.UUID)
+    ids_param = next(p for p in parameters if p["name"] == "ids")
+    assert ids_param["in"] == "query"
+    assert ids_param["required"] is False
+    assert "oneOf" in ids_param["schema"]
+    assert len(ids_param["schema"]["oneOf"]) == 2
+    array_schema = ids_param["schema"]["oneOf"][0]
+    assert array_schema["type"] == "array"
+    assert array_schema["items"]["type"] == "string"
+
+    # createdBefore (datetime parameter)
+    created_before_param = next(p for p in parameters if p["name"] == "createdBefore")
+    assert created_before_param["in"] == "query"
+    assert created_before_param["required"] is False
+    assert "oneOf" in created_before_param["schema"]
+    date_schema = created_before_param["schema"]["oneOf"][0]
+    assert date_schema["type"] == "string"
+    assert date_schema["format"] == "date-time"
+
+    # Check in and not_in parameters
+    status_not_in_param = next(p for p in parameters if p["name"] == "statusNotIn")
+    assert status_not_in_param["in"] == "query"
+    assert status_not_in_param["required"] is False
+    assert "oneOf" in status_not_in_param["schema"]
+
+    tag_in_param = next(p for p in parameters if p["name"] == "tagIn")
+    assert tag_in_param["in"] == "query"
+    assert tag_in_param["required"] is False
+    assert "oneOf" in tag_in_param["schema"]
